@@ -76,7 +76,9 @@ def Mqtt():
         # 连接broker，心跳时间为60s
         mqttc.connect(server_url, server_port, 60)
         # 订阅该主题，QoS=0
-        threading.Thread(target=mqttc.loop_forever).start()
+        t = threading.Thread(target=mqttc.loop_forever)
+        t.daemon = True
+        t.start()
     return mqttc
 
 
